``baseplate.lib.crypto``
========================

.. automodule:: baseplate.lib.crypto

Message Signing
---------------

.. autofunction:: make_signature

.. autofunction:: validate_signature

.. autoclass:: SignatureInfo

Exceptions
~~~~~~~~~~

.. autoexception:: SignatureError

.. autoexception:: UnreadableSignatureError

.. autoexception:: IncorrectSignatureError

.. autoexception:: ExpiredSignatureError
